@@ -1,5 +1,5 @@
 /* base32.c -- Encode binary data using printable characters.
-   Copyright (C) 1999-2001, 2004-2006, 2009-2025 Free Software Foundation, Inc.
+   Copyright (C) 1999-2001, 2004-2006, 2009-2026 Free Software Foundation, Inc.
 
    This file is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
@@ -37,10 +37,10 @@
  *
  */
 
+#define BASE32_INLINE _GL_EXTERN_INLINE
 #include <config.h>
 
 /* Get prototype. */
-#define BASE32_INLINE _GL_EXTERN_INLINE
 #include "base32.h"
 
 /* Get imalloc. */
@@ -335,13 +335,14 @@ static bool
 decode_8 (char const *restrict in, idx_t inlen,
           char *restrict *outp, idx_t *outleft)
 {
-  char *out = *outp;
   if (inlen < 8)
     return false;
 
   if (!isbase32 (in[0]) || !isbase32 (in[1]))
     return false;
 
+  char *out = *outp;
+
   if (*outleft)
     {
       *out++ = ((base32_to_int[to_uchar (in[0])] << 3)
@@ -446,7 +447,6 @@ base32_decode_ctx (struct base32_decode_context *ctx,
                    const char *restrict in, idx_t inlen,
                    char *restrict out, idx_t *outlen)
 {
-  idx_t outleft = *outlen;
   bool ignore_newlines = ctx != NULL;
   bool flush_ctx = false;
   unsigned int ctx_i = 0;
@@ -457,6 +457,7 @@ base32_decode_ctx (struct base32_decode_context *ctx,
       flush_ctx = inlen == 0;
     }
 
+  idx_t outleft = *outlen;
 
   while (true)
     {
@@ -485,35 +486,36 @@ base32_decode_ctx (struct base32_decode_context *ctx,
         {
           ++in;
           --inlen;
-          continue;
         }
+      else
+        {
+          /* Restore OUT and OUTLEFT.  */
+          out -= outleft_save - outleft;
+          outleft = outleft_save;
 
-      /* Restore OUT and OUTLEFT.  */
-      out -= outleft_save - outleft;
-      outleft = outleft_save;
-
-      {
-        char const *in_end = in + inlen;
-        char const *non_nl;
-
-        if (ignore_newlines)
-          non_nl = get_8 (ctx, &in, in_end, &inlen);
-        else
-          non_nl = in;  /* Might have nl in this case. */
-
-        /* If the input is empty or consists solely of newlines (0 non-newlines),
-           then we're done.  Likewise if there are fewer than 8 bytes when not
-           flushing context and not treating newlines as garbage.  */
-        if (inlen == 0 || (inlen < 8 && !flush_ctx && ignore_newlines))
           {
-            inlen = 0;
-            break;
-          }
-        if (!decode_8 (non_nl, inlen, &out, &outleft))
-          break;
+            char const *in_end = in + inlen;
 
-        inlen = in_end - in;
-      }
+            char const *non_nl;
+            if (ignore_newlines)
+              non_nl = get_8 (ctx, &in, in_end, &inlen);
+            else
+              non_nl = in;  /* Might have nl in this case. */
+
+            /* If the input is empty or consists solely of newlines (0 non-newlines),
+               then we're done.  Likewise if there are fewer than 8 bytes when not
+               flushing context and not treating newlines as garbage.  */
+            if (inlen == 0 || (inlen < 8 && !flush_ctx && ignore_newlines))
+              {
+                inlen = 0;
+                break;
+              }
+            if (!decode_8 (non_nl, inlen, &out, &outleft))
+              break;
+
+            inlen = in_end - in;
+          }
+        }
     }
 
   *outlen -= outleft;
